==> qt-creator-opensource-src-4.2.0.zip: qt-creator-opensource-src-4.2.0/src/shared/qbs/src/lib/corelib/jsextensions/propertylistutils.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Copyright (C) 2014 Petroules Corporation.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QPROPERTYLISTUTILS_H
#define QPROPERTYLISTUTILS_H

#include <QVariant>
#import <Foundation/Foundation.h>

#if !defined(__OBJC__) || !defined(__cplusplus)
#error "This file must be included from Objective-C++"
#endif

class QPropertyListUtils
{
    Q_DISABLE_COPY(QPropertyListUtils)

public:
    static QVariant fromPropertyList(id plist);
    static id toPropertyList(const QVariant &map);

private:
    QPropertyListUtils();
};

template <typename Key, typename T>
QMap<Key, T> qHashToMap(const QHash<Key, T> &hash) {
    QMap<Key, T> map;
    QHashIterator<Key, T> i(hash);
    while (i.hasNext()) {
        i.next();
        map.insert(i.key(), i.value());
    }
    return map;
}

#endif // QPROPERTYLISTUTILS_H

==> qt-creator-opensource-src-18.0.1.zip: qt-creator-opensource-src-18.0.1/src/shared/qbs/src/lib/corelib/jsextensions/propertylistutils.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Copyright (C) 2014 Petroules Corporation.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QPROPERTYLISTUTILS_H
#define QPROPERTYLISTUTILS_H

#include <QtCore/qvariant.h>
#import <Foundation/Foundation.h>

#if !defined(__OBJC__) || !defined(__cplusplus)
#error "This file must be included from Objective-C++"
#endif

class QPropertyListUtils
{
    Q_DISABLE_COPY(QPropertyListUtils)

public:
    static QVariant fromPropertyList(id plist);
    static id toPropertyList(const QVariant &map);

private:
    QPropertyListUtils();
};

template <typename Key, typename T>
QMap<Key, T> qHashToMap(const QHash<Key, T> &hash) {
    QMap<Key, T> map;
    for (auto i = hash.cbegin(), end = hash.cend(); i != end; ++i)
        map.insert(i.key(), i.value());
    return map;
}

#endif // QPROPERTYLISTUTILS_H
